@@ -7,11 +7,12 @@ define([
   './directives/index',
   './controllers/index',
   './filters/index',
+  './factories/index',
   './run/index',
   './config/index',
   'chart',
-  'angularChart'
-], function(ng) {
+  'angularChart',
+], function (ng) {
   'use strict'
   return ng.module('wazuhApp', [
     'ngMaterial',
@@ -21,7 +22,8 @@ define([
     'app.directives',
     'app.controllers',
     'app.filter',
+    'app.factories',
     'app.run',
-    'app.config'
+    'app.config',
   ])
 })
