@@ -1,7 +1,7 @@
-define(['../module'], function(module) {
+define(['../module'], function (module) {
   'use strict'
   module.paths = {
-    root: `${window.location.href.split(/\/[a-z][a-z]-[A-Z][A-Z]\//)[0]}/`
+    root: `${window.location.href.split(/\/[a-z][a-z]-[A-Z][A-Z]\//)[0]}/`,
   }
   module.constant('BASE_URL', module.paths.root)
   module.config([
@@ -10,7 +10,7 @@ define(['../module'], function(module) {
     '$stateProvider',
     '$mdThemingProvider',
     'BASE_URL',
-    function(
+    function (
       $mdIconProvider,
       $locationProvider,
       $stateProvider,
@@ -24,7 +24,7 @@ define(['../module'], function(module) {
       $locationProvider.html5Mode({
         enabled: true,
         requirebase: false,
-        rewriteLinks: false
+        rewriteLinks: false,
       })
       $stateProvider
         .state('overview', {
@@ -33,27 +33,47 @@ define(['../module'], function(module) {
             'static/app/SplunkAppForWazuh/js/controllers/overview/welcome/overview-welcome.html',
           controller: 'overviewWelcomeCtrl',
           resolve: {
+            updateUserPermissions: [
+              '$security_service',
+              async ($security_service) => {
+                return await $security_service.updateUserPermissions()
+              },
+            ],
+            isSplunkAdmin: [
+              '$splunkUsers',
+              async ($splunkUsers) => {
+                try {
+                  return await $splunkUsers.isAdmin()
+                } catch (err) {
+                  return {
+                    error: 'Cannot fetch Splunk users from API',
+                    detail: err,
+                  }
+                }
+              },
+            ],
             agentsInfo: [
               '$requestService',
-              '$state',
-              async $requestService => {
+              async ($requestService) => {
                 try {
-                  const result = await $requestService.apiReq('/agents/summary/status')
+                  const result = await $requestService.apiReq(
+                    '/agents/summary/status'
+                  )
                   return result
                 } catch (err) {} //eslint-disable-line
-              }
+              },
             ],
             extensions: [
               '$currentDataService',
-              async $currentDataService => {
+              async ($currentDataService) => {
                 try {
                   return await $currentDataService.getCurrentExtensions()
                 } catch (err) {
                   return false
                 }
-              }
-            ]
-          }
+              },
+            ],
+          },
         })
 
         // Overview - General
@@ -61,15 +81,20 @@ define(['../module'], function(module) {
           templateUrl:
             BASE_URL +
             'static/app/SplunkAppForWazuh/js/controllers/overview/general/overview-general.html',
-          onEnter: $navigationService => {
+          onEnter: ($navigationService) => {
             $navigationService.storeRoute('ow-general')
           },
           controller: 'overviewGeneralCtrl',
           resolve: {
+            updateUserPermissions: [
+              '$security_service',
+              async ($security_service) => {
+                return await $security_service.updateUserPermissions()
+              },
+            ],
             pollingState: [
               '$requestService',
-              '$state',
-              async ($requestService, $state) => {
+              async ($requestService) => {
                 try {
                   const result = await $requestService.httpReq(
                     `GET`,
@@ -77,223 +102,264 @@ define(['../module'], function(module) {
                   )
                   return result
                 } catch (err) {
-                  $state.go('settings.api')
+                  return false
                 }
-              }
+              },
             ],
             reportingEnabled: [
               '$currentDataService',
-              async $currentDataService => {
+              async ($currentDataService) => {
                 return await $currentDataService.getReportingStatus()
-              }
+              },
             ],
             awsExtensionEnabled: [
               '$currentDataService',
-              async $currentDataService => {
+              async ($currentDataService) => {
                 try {
                   return await $currentDataService.extensionIsEnabled('aws')
                 } catch (err) {
                   return false
                 }
-              }
-            ]
-          }
+              },
+            ],
+          },
         })
         // Overview - policy monitoring
         .state('ow-pm', {
           templateUrl:
             BASE_URL +
             'static/app/SplunkAppForWazuh/js/controllers/overview/policy-monitoring/overview-pm.html',
-          onEnter: $navigationService => {
+          onEnter: ($navigationService) => {
             $navigationService.storeRoute('ow-pm')
           },
           controller: 'overviewPolicyMonitoringCtrl',
           resolve: {
+            updateUserPermissions: [
+              '$security_service',
+              async ($security_service) => {
+                return await $security_service.updateUserPermissions()
+              },
+            ],
             reportingEnabled: [
               '$currentDataService',
-              async $currentDataService => {
+              async ($currentDataService) => {
                 return await $currentDataService.getReportingStatus()
-              }
+              },
             ],
             extensions: [
               '$currentDataService',
-              async $currentDataService => {
+              async ($currentDataService) => {
                 try {
                   return await $currentDataService.getCurrentExtensions()
                 } catch (err) {
                   return false
                 }
-              }
-            ]
-          }
-        }) // Overview - SCA Security Configuration Assessment
+              },
+            ],
+          },
+        })
+        // Overview - SCA Security Configuration Assessment
         .state('ow-sca', {
           templateUrl:
             BASE_URL +
             'static/app/SplunkAppForWazuh/js/controllers/overview/sca/overview-sca.html',
-          onEnter: $navigationService => {
+          onEnter: ($navigationService) => {
             $navigationService.storeRoute('ow-sca')
           },
           controller: 'overviewSCACtrl',
           resolve: {
+            updateUserPermissions: [
+              '$security_service',
+              async ($security_service) => {
+                return await $security_service.updateUserPermissions()
+              },
+            ],
             reportingEnabled: [
               '$currentDataService',
-              async $currentDataService => {
+              async ($currentDataService) => {
                 return await $currentDataService.getReportingStatus()
-              }
+              },
             ],
             extensions: [
               '$currentDataService',
-              async $currentDataService => {
+              async ($currentDataService) => {
                 try {
                   return await $currentDataService.getCurrentExtensions()
                 } catch (err) {
                   return false
                 }
-              }
-            ]
-          }
+              },
+            ],
+          },
         })
         // Overview - FIM
         .state('ow-fim', {
           templateUrl:
             BASE_URL +
             'static/app/SplunkAppForWazuh/js/controllers/overview/fim/overview-fim.html',
-          onEnter: $navigationService => {
+          onEnter: ($navigationService) => {
             $navigationService.storeRoute('ow-fim')
           },
           controller: 'overviewFimCtrl',
           resolve: {
+            updateUserPermissions: [
+              '$security_service',
+              async ($security_service) => {
+                return await $security_service.updateUserPermissions()
+              },
+            ],
             reportingEnabled: [
               '$currentDataService',
-              async $currentDataService => {
+              async ($currentDataService) => {
                 return await $currentDataService.getReportingStatus()
-              }
+              },
             ],
             awsExtensionEnabled: [
               '$currentDataService',
-              async $currentDataService => {
+              async ($currentDataService) => {
                 try {
                   return await $currentDataService.extensionIsEnabled('aws')
                 } catch (err) {
                   return false
                 }
-              }
-            ]
-          }
+              },
+            ],
+          },
         })
         // Overview - Osquery
         .state('ow-osquery', {
           templateUrl:
             BASE_URL +
             'static/app/SplunkAppForWazuh/js/controllers/overview/osquery/osquery.html',
-          onEnter: $navigationService => {
+          onEnter: ($navigationService) => {
             $navigationService.storeRoute('ow-osquery')
           },
           controller: 'osqueryCtrl',
           resolve: {
+            updateUserPermissions: [
+              '$security_service',
+              async ($security_service) => {
+                return await $security_service.updateUserPermissions()
+              },
+            ],
             osquery: [
               '$requestService',
-              '$state',
-              async ($requestService, $state) => {
+              async ($requestService) => {
                 try {
                   const result = await $requestService.apiReq(
                     `/agents/000/config/wmodules/wmodules`
                   )
                   return result
                 } catch (err) {
-                  $state.go('settings.api')
+                  return false
                 }
-              }
+              },
             ],
             reportingEnabled: [
               '$currentDataService',
-              async $currentDataService => {
+              async ($currentDataService) => {
                 return await $currentDataService.getReportingStatus()
-              }
+              },
             ],
             extensions: [
               '$currentDataService',
-              async $currentDataService => {
+              async ($currentDataService) => {
                 try {
                   return await $currentDataService.getCurrentExtensions()
                 } catch (err) {
                   return false
                 }
-              }
-            ]
-          }
+              },
+            ],
+          },
         })
         // Overview - audit
         .state('ow-audit', {
           templateUrl:
             BASE_URL +
             'static/app/SplunkAppForWazuh/js/controllers/overview/audit/overview-audit.html',
-          onEnter: $navigationService => {
+          onEnter: ($navigationService) => {
             $navigationService.storeRoute('ow-audit')
           },
           controller: 'overviewAuditCtrl',
           resolve: {
+            updateUserPermissions: [
+              '$security_service',
+              async ($security_service) => {
+                return await $security_service.updateUserPermissions()
+              },
+            ],
             reportingEnabled: [
               '$currentDataService',
-              async $currentDataService => {
+              async ($currentDataService) => {
                 return await $currentDataService.getReportingStatus()
-              }
+              },
             ],
             extensions: [
               '$currentDataService',
-              async $currentDataService => {
+              async ($currentDataService) => {
                 try {
                   return await $currentDataService.getCurrentExtensions()
                 } catch (err) {
                   return false
                 }
-              }
-            ]
-          }
+              },
+            ],
+          },
         })
         // Overview - OpenSCAP
         .state('ow-os', {
           templateUrl:
             BASE_URL +
             'static/app/SplunkAppForWazuh/js/controllers/overview/scap/overview-openscap.html',
-          onEnter: $navigationService => {
+          onEnter: ($navigationService) => {
             $navigationService.storeRoute('ow-os')
           },
           controller: 'overviewOpenScapCtrl',
           resolve: {
+            updateUserPermissions: [
+              '$security_service',
+              async ($security_service) => {
+                return await $security_service.updateUserPermissions()
+              },
+            ],
             reportingEnabled: [
               '$currentDataService',
-              async $currentDataService => {
+              async ($currentDataService) => {
                 return await $currentDataService.getReportingStatus()
-              }
+              },
             ],
             extensions: [
               '$currentDataService',
-              async $currentDataService => {
+              async ($currentDataService) => {
                 try {
                   return await $currentDataService.getCurrentExtensions()
                 } catch (err) {
                   return false
                 }
-              }
-            ]
-          }
+              },
+            ],
+          },
         })
         // Overview - PCI-DSS
         .state('ow-pci', {
           templateUrl:
             BASE_URL +
             'static/app/SplunkAppForWazuh/js/controllers/overview/pci/overview-pci.html',
-          onEnter: $navigationService => {
+          onEnter: ($navigationService) => {
             $navigationService.storeRoute('ow-pci')
           },
           controller: 'overviewPciCtrl',
           resolve: {
+            updateUserPermissions: [
+              '$security_service',
+              async ($security_service) => {
+                return await $security_service.updateUserPermissions()
+              },
+            ],
             pciTabs: [
               '$requestService',
-              '$state',
-              async ($requestService, $state) => {
+              async ($requestService) => {
                 try {
                   const pciTabs = []
                   const data = await $requestService.httpReq(
@@ -306,62 +372,67 @@ define(['../module'], function(module) {
                   }
                   return pciTabs
                 } catch (err) {
-                  $state.go('settings.api')
+                  return false
                 }
-              }
+              },
             ],
             reportingEnabled: [
               '$currentDataService',
-              async $currentDataService => {
+              async ($currentDataService) => {
                 return await $currentDataService.getReportingStatus()
-              }
+              },
             ],
             gdprExtensionEnabled: [
               '$currentDataService',
-              async $currentDataService => {
+              async ($currentDataService) => {
                 try {
                   return await $currentDataService.extensionIsEnabled('gdpr')
                 } catch (err) {
                   return false
                 }
-              }
+              },
             ],
             hipaaExtensionEnabled: [
               '$currentDataService',
-              async $currentDataService => {
+              async ($currentDataService) => {
                 try {
                   return await $currentDataService.extensionIsEnabled('hipaa')
                 } catch (err) {
                   return false
                 }
-              }
+              },
             ],
             nistExtensionEnabled: [
               '$currentDataService',
-              async $currentDataService => {
+              async ($currentDataService) => {
                 try {
                   return await $currentDataService.extensionIsEnabled('nist')
                 } catch (err) {
                   return false
                 }
-              }
-            ]
-          }
+              },
+            ],
+          },
         })
         // Overview - GDPR
         .state('ow-gdpr', {
           templateUrl:
             BASE_URL +
             'static/app/SplunkAppForWazuh/js/controllers/overview/gdpr/overview-gdpr.html',
-          onEnter: $navigationService => {
+          onEnter: ($navigationService) => {
             $navigationService.storeRoute('ow-gdpr')
           },
           controller: 'overviewGdprCtrl',
           resolve: {
+            updateUserPermissions: [
+              '$security_service',
+              async ($security_service) => {
+                return await $security_service.updateUserPermissions()
+              },
+            ],
             gdprTabs: [
               '$requestService',
-              '$state',
-              async ($requestService, $state) => {
+              async ($requestService) => {
                 try {
                   const gdprTabs = []
                   const data = await $requestService.httpReq(
@@ -374,61 +445,67 @@ define(['../module'], function(module) {
                   }
                   return gdprTabs
                 } catch (err) {
-                  $state.go('settings.api')
+                  return false
                 }
-              }
+              },
             ],
             reportingEnabled: [
               '$currentDataService',
-              async $currentDataService => {
+              async ($currentDataService) => {
                 return await $currentDataService.getReportingStatus()
-              }
+              },
             ],
             pciExtensionEnabled: [
               '$currentDataService',
-              async $currentDataService => {
+              async ($currentDataService) => {
                 try {
                   return await $currentDataService.extensionIsEnabled('pci')
                 } catch (err) {
                   return false
                 }
-              }
+              },
             ],
             hipaaExtensionEnabled: [
               '$currentDataService',
-              async $currentDataService => {
+              async ($currentDataService) => {
                 try {
                   return await $currentDataService.extensionIsEnabled('hipaa')
                 } catch (err) {
                   return false
                 }
-              }
+              },
             ],
             nistExtensionEnabled: [
               '$currentDataService',
-              async $currentDataService => {
+              async ($currentDataService) => {
                 try {
                   return await $currentDataService.extensionIsEnabled('nist')
                 } catch (err) {
                   return false
                 }
-              }
-            ]
-          }
-        }) // Overview - HIPAA
+              },
+            ],
+          },
+        })
+        // Overview - HIPAA
         .state('ow-hipaa', {
           templateUrl:
             BASE_URL +
             'static/app/SplunkAppForWazuh/js/controllers/overview/hipaa/overview-hipaa.html',
-          onEnter: $navigationService => {
+          onEnter: ($navigationService) => {
             $navigationService.storeRoute('ow-hipaa')
           },
           controller: 'overviewHipaaCtrl',
           resolve: {
+            updateUserPermissions: [
+              '$security_service',
+              async ($security_service) => {
+                return await $security_service.updateUserPermissions()
+              },
+            ],
             hipaaTabs: [
               '$requestService',
-              '$state',
-              async ($requestService, $state) => {
+              async ($requestService) => {
                 try {
                   const hipaaTabs = []
                   const data = await $requestService.httpReq(
@@ -441,62 +518,67 @@ define(['../module'], function(module) {
                   }
                   return hipaaTabs
                 } catch (err) {
-                  $state.go('settings.api')
+                  return false
                 }
-              }
+              },
             ],
             reportingEnabled: [
               '$currentDataService',
-              async $currentDataService => {
+              async ($currentDataService) => {
                 return await $currentDataService.getReportingStatus()
-              }
+              },
             ],
             pciExtensionEnabled: [
               '$currentDataService',
-              async $currentDataService => {
+              async ($currentDataService) => {
                 try {
                   return await $currentDataService.extensionIsEnabled('pci')
                 } catch (err) {
                   return false
                 }
-              }
+              },
             ],
             gdprExtensionEnabled: [
               '$currentDataService',
-              async $currentDataService => {
+              async ($currentDataService) => {
                 try {
                   return await $currentDataService.extensionIsEnabled('gdpr')
                 } catch (err) {
                   return false
                 }
-              }
+              },
             ],
             nistExtensionEnabled: [
               '$currentDataService',
-              async $currentDataService => {
+              async ($currentDataService) => {
                 try {
                   return await $currentDataService.extensionIsEnabled('nist')
                 } catch (err) {
                   return false
                 }
-              }
-            ]
-          }
+              },
+            ],
+          },
         })
         // Overview - NIST 800-53
         .state('ow-nist', {
           templateUrl:
             BASE_URL +
             'static/app/SplunkAppForWazuh/js/controllers/overview/nist/overview-nist.html',
-          onEnter: $navigationService => {
+          onEnter: ($navigationService) => {
             $navigationService.storeRoute('ow-nist')
           },
           controller: 'overviewNistCtrl',
           resolve: {
+            updateUserPermissions: [
+              '$security_service',
+              async ($security_service) => {
+                return await $security_service.updateUserPermissions()
+              },
+            ],
             nistTabs: [
               '$requestService',
-              '$state',
-              async ($requestService, $state) => {
+              async ($requestService) => {
                 try {
                   const nistTabs = []
                   const data = await $requestService.httpReq(
@@ -509,251 +591,305 @@ define(['../module'], function(module) {
                   }
                   return nistTabs
                 } catch (err) {
-                  $state.go('settings.api')
+                  return false
                 }
-              }
+              },
             ],
             reportingEnabled: [
               '$currentDataService',
-              async $currentDataService => {
+              async ($currentDataService) => {
                 return await $currentDataService.getReportingStatus()
-              }
+              },
             ],
             pciExtensionEnabled: [
               '$currentDataService',
-              async $currentDataService => {
+              async ($currentDataService) => {
                 try {
                   return await $currentDataService.extensionIsEnabled('pci')
                 } catch (err) {
                   return false
                 }
-              }
+              },
             ],
             gdprExtensionEnabled: [
               '$currentDataService',
-              async $currentDataService => {
+              async ($currentDataService) => {
                 try {
                   return await $currentDataService.extensionIsEnabled('gdpr')
                 } catch (err) {
                   return false
                 }
-              }
+              },
             ],
             hipaaExtensionEnabled: [
               '$currentDataService',
-              async $currentDataService => {
+              async ($currentDataService) => {
                 try {
                   return await $currentDataService.extensionIsEnabled('hipaa')
                 } catch (err) {
                   return false
                 }
-              }
-            ]
-          }
+              },
+            ],
+          },
         })
         // Overview - Vulnerabilities
         .state('ow-vul', {
           templateUrl:
             BASE_URL +
             'static/app/SplunkAppForWazuh/js/controllers/overview/vulnerabilities/overview-vulnerabilities.html',
-          onEnter: $navigationService => {
+          onEnter: ($navigationService) => {
             $navigationService.storeRoute('ow-vul')
           },
           controller: 'overviewVulnerabilitiesCtrl',
           resolve: {
+            updateUserPermissions: [
+              '$security_service',
+              async ($security_service) => {
+                return await $security_service.updateUserPermissions()
+              },
+            ],
             reportingEnabled: [
               '$currentDataService',
-              async $currentDataService => {
+              async ($currentDataService) => {
                 return await $currentDataService.getReportingStatus()
-              }
+              },
             ],
             extensions: [
               '$currentDataService',
-              async $currentDataService => {
+              async ($currentDataService) => {
                 try {
                   return await $currentDataService.getCurrentExtensions()
                 } catch (err) {
                   return false
                 }
-              }
-            ]
-          }
+              },
+            ],
+          },
         })
         // Overview - CIS-CAT
         .state('ow-ciscat', {
           templateUrl:
             BASE_URL +
             'static/app/SplunkAppForWazuh/js/controllers/overview/ciscat/overview-ciscat.html',
-          onEnter: $navigationService => {
+          onEnter: ($navigationService) => {
             $navigationService.storeRoute('ow-ciscat')
           },
           controller: 'ciscatCtrl',
           resolve: {
+            updateUserPermissions: [
+              '$security_service',
+              async ($security_service) => {
+                return await $security_service.updateUserPermissions()
+              },
+            ],
             reportingEnabled: [
               '$currentDataService',
-              async $currentDataService => {
+              async ($currentDataService) => {
                 return await $currentDataService.getReportingStatus()
-              }
+              },
             ],
             extensions: [
               '$currentDataService',
-              async $currentDataService => {
+              async ($currentDataService) => {
                 try {
                   return await $currentDataService.getCurrentExtensions()
                 } catch (err) {
                   return false
                 }
-              }
-            ]
-          }
+              },
+            ],
+          },
         })
         // Overview - VirusTotal
         .state('ow-virustotal', {
           templateUrl:
             BASE_URL +
             'static/app/SplunkAppForWazuh/js/controllers/overview/virustotal/overview-virustotal.html',
-          onEnter: $navigationService => {
+          onEnter: ($navigationService) => {
             $navigationService.storeRoute('ow-virustotal')
           },
           controller: 'overviewVirusTotal',
           resolve: {
+            updateUserPermissions: [
+              '$security_service',
+              async ($security_service) => {
+                return await $security_service.updateUserPermissions()
+              },
+            ],
             reportingEnabled: [
               '$currentDataService',
-              async $currentDataService => {
+              async ($currentDataService) => {
                 return await $currentDataService.getReportingStatus()
-              }
+              },
             ],
             extensions: [
               '$currentDataService',
-              async $currentDataService => {
+              async ($currentDataService) => {
                 try {
                   return await $currentDataService.getCurrentExtensions()
                 } catch (err) {
                   return false
                 }
-              }
-            ]
-          }
+              },
+            ],
+          },
         })
         // =========== AWS =========== //
         .state('ow-aws', {
           templateUrl:
             BASE_URL +
             'static/app/SplunkAppForWazuh/js/controllers/overview/aws/aws.html',
-          onEnter: $navigationService => {
+          onEnter: ($navigationService) => {
             $navigationService.storeRoute('ow-aws')
           },
           controller: 'awsCtrl',
           resolve: {
+            updateUserPermissions: [
+              '$security_service',
+              async ($security_service) => {
+                return await $security_service.updateUserPermissions()
+              },
+            ],
             reportingEnabled: [
               '$currentDataService',
-              async $currentDataService => {
+              async ($currentDataService) => {
                 return await $currentDataService.getReportingStatus()
-              }
-            ]
-          }
+              },
+            ],
+          },
         })
         // =========== Docker listener =========== //
         .state('ow-docker', {
           templateUrl:
             BASE_URL +
             'static/app/SplunkAppForWazuh/js/controllers/overview/docker/overview-docker.html',
-          onEnter: $navigationService => {
+          onEnter: ($navigationService) => {
             $navigationService.storeRoute('ow-docker')
           },
           controller: 'dockerCtrl',
           resolve: {
+            updateUserPermissions: [
+              '$security_service',
+              async ($security_service) => {
+                return await $security_service.updateUserPermissions()
+              },
+            ],
             reportingEnabled: [
               '$currentDataService',
-              async $currentDataService => {
+              async ($currentDataService) => {
                 return await $currentDataService.getReportingStatus()
-              }
+              },
             ],
             extensions: [
               '$currentDataService',
-              async $currentDataService => {
+              async ($currentDataService) => {
                 try {
                   return await $currentDataService.getCurrentExtensions()
                 } catch (err) {
                   return false
                 }
-              }
-            ]
-          }
+              },
+            ],
+          },
         })
         // =========== MITRE ATT&CK =========== //
         .state('ow-mitre', {
           templateUrl:
             BASE_URL +
             'static/app/SplunkAppForWazuh/js/controllers/overview/mitre/overview-mitre.html',
-          onEnter: $navigationService => {
+          onEnter: ($navigationService) => {
             $navigationService.storeRoute('ow-mitre')
           },
           controller: 'overviewMitreCtrl',
           resolve: {
+            updateUserPermissions: [
+              '$security_service',
+              async ($security_service) => {
+                return await $security_service.updateUserPermissions()
+              },
+            ],
             reportingEnabled: [
               '$currentDataService',
-              async $currentDataService => {
+              async ($currentDataService) => {
                 return await $currentDataService.getReportingStatus()
-              }
+              },
             ],
             extensions: [
               '$currentDataService',
-              async $currentDataService => {
+              async ($currentDataService) => {
                 try {
                   return await $currentDataService.getCurrentExtensions()
                 } catch (err) {
                   return false
                 }
-              }
-            ]
-          }
+              },
+            ],
+          },
         })
         // =========== MITRE ATT&CK Framework =========== //
         .state('ow-mitre-ids', {
           templateUrl:
             BASE_URL +
             'static/app/SplunkAppForWazuh/js/controllers/overview/mitre-ids/overview-mitre-ids.html',
-          onEnter: $navigationService => {
+          onEnter: ($navigationService) => {
             $navigationService.storeRoute('ow-mitre-ids')
           },
           controller: 'overviewMitreIdsCtrl',
           resolve: {
+            updateUserPermissions: [
+              '$security_service',
+              async ($security_service) => {
+                return await $security_service.updateUserPermissions()
+              },
+            ],
             mitre_tactics: [
               '$requestService',
-              '$state',
-              async (
-                $requestService,
-                $state
-              ) => {
+              async ($requestService) => {
                 try {
-                  const results = await $requestService.apiReq(`/mitre?select=phase_name`)
-                  const data = results.data.data.affected_items
-                  
-                  const tactics = data.reduce((parsed, item)=>{
-                    parsed[item.phase_name[0]]=0
-                    return parsed
-                  },{})
-
-                  return tactics
+                  const fields = [
+                    'name',
+                  ].join()
 
+                  const results = await $requestService.apiReq(
+                    `/mitre/tactics?select=${fields}`
+                  )
+                  return results.data.data.affected_items
                 } catch (err) {
-                  $state.go('overview')
+                  return false
                 }
-              }
+              },
+            ],
+            mitre_techniques: [
+              '$requestService',
+              async ($requestService) => {
+                try {
+                  const fields = [
+                    'name',
+                    'external_id',
+                  ].join()
+
+                  const results = await $requestService.apiReq(
+                    `/mitre/techniques?select=${fields}&limit=1000`
+                  )
+                  return results.data.data.affected_items
+                } catch (err) {
+                  return false
+                }
+              },
             ],
             extensions: [
               '$currentDataService',
-              async $currentDataService => {
+              async ($currentDataService) => {
                 try {
                   return await $currentDataService.getCurrentExtensions()
                 } catch (err) {
                   return false
                 }
-              }
-            ]
-          }
+              },
+            ],
+          },
         })
-    }
+    },
   ])
 })
