@@ -10,17 +10,17 @@
  * Find more information about this on the LICENSE file.
  */
 
-define(['../module'], function(directives) {
+define(['../module'], function (directives) {
   'use strict'
-  directives.directive('wzNoConfig', function(BASE_URL) {
+  directives.directive('wzNoConfig', function (BASE_URL) {
     return {
       restrict: 'E',
       scope: {
-        error: '=error'
+        error: '=error',
       },
       templateUrl:
         BASE_URL +
-        '/static/app/SplunkAppForWazuh/js/directives/wz-no-config/wz-no-config.html'
+        '/static/app/SplunkAppForWazuh/js/directives/wz-no-config/wz-no-config.html',
     }
   })
 })
